@@ -437,6 +437,16 @@ class LocalPorvider(BaseProvider):
         """
         return InstSP.ashare_suspension(stkcode, fields)
 
+    def ashare_isparticipant(self, stkcode=None, fields=None):
+        """ 
+            table_name: 'AShareISParticipant'
+            input:instruments:List(str),fields:List(str)
+                  optional: stkcode = None,fields =None
+            output: DataFrame
+            fields : suspend_date,resump_date           
+        """
+        return InstSP.ashare_isparticipant(stkcode, fields)
+
     def suntime_typedict(self, organid=None, fields=None):
         """ 
             table_name: 'RPT_RATING_COMPARE'
@@ -663,6 +673,26 @@ class LocalPorvider(BaseProvider):
         """
         return FRP.repo_ashare_dividend(instruments, fields, **kws)
 
+    def repo_isactivity(self,instruments,fields,**kws):
+        """
+            table_name: 'AShareISActivity'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_isactivity(instruments, fields, **kws)
+
+    def repo_isqa(self,instruments,fields,**kws):
+        """
+            table_name: 'AShareISQA'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_isqa(instruments, fields, **kws)
+
     def frepo_qdii_secuportfolio(self, instruments, fields=None, **kws):
         """
             table_name: 'QDIISecuritiesPortfolio'
