@@ -14,6 +14,8 @@ aindex_altermember = os.path.join(data_path,r'AIndexAlternativeMembers')
 ashare_description = os.path.join(data_path,r'AShareDescription')
 ashare_st = os.path.join(data_path,r'AShareST')
 ashare_suspension = os.path.join(data_path,r'AShareTradingSuspension')
+ashare_isparticipant = os.path.join(data_path,r'AShareISParticipant')
+
 suntime_typedict = os.path.join(data_path,r'RPT_RATING_COMPARE')
 cfutures_contract_mapping = os.path.join(data_path,r'CFuturesContractMapping')   
 
@@ -24,6 +26,7 @@ ashare_idu_sw = os.path.join(data_path,r'AShareIndustriesClass_SW')
 ashare_idu_wind = os.path.join(data_path,r'AShareIndustriesClass_WIND')
 ashare_idu_code = os.path.join(data_path,r'AShareIndustriesCode')
 
+
 class BaseStatusInfoProvider(abc.ABC):
 
     @abc.abstractmethod
@@ -111,6 +114,11 @@ class LocalInstStatusProvider(BaseStatusInfoProvider):
         """ AIndexMembers """
         return self.get_status_data(ashare_suspension,stkcode,fields)   
 
+    @print_func_time
+    def ashare_isparticipant(self,stkcode,fields = None):
+        """ AIndexMembers """
+        return self.get_status_data(ashare_isparticipant,stkcode,fields)   
+
     @print_func_time
     def suntime_typedict(self,organcode,fields = None):
         """RPT_RATING_COMPARE"""
